SET mapreduce.job.queuename=data;
SET mapreduce.map.memory.mb=8192;
SET mapreduce.map.java.opts=-Xmx8000m;
SET mapreduce.reduce.memory.mb=8192;
SET mapreduce.reduce.java.opts=-Xmx8000m;
set hive.auto.convert.join=true;
SET mapred.reduce.tasks=20;
SET role admin;

--内容日报简化
INSERT OVERWRITE TABLE pm.tl_pm_content_v2 PARTITION (PARTITION_DAY = ${partition_day})

SELECT
        t1.partition_date as day_id
        ,t1.device_os_type
        ,t1.active_type
        ,t1.channel
        ,dau
        ,NVL(ROUND(retention_num2/dau*100,2),0) AS retention_rate2
        ,NVL(ROUND(retention_num3/dau*100,2),0) AS retention_rate3
        ,NVL(ROUND(retention_num7/dau*100,2),0) AS retention_rate7
        ,NVL(t2.home_click_uv,0) AS home_card_click_uv
        ,NVL(t2.home_click_pv,0) AS home_card_click_pv
        ,NVL(t2.good_pv,0) AS home_good_click
        ,NVL(t2.avg_page_stay,0) AS page_stay_per_device
        ,NVL(t3.ai_report_uv,0) AS ai_report_uv
        ,NVL(t3.ai_click_uv,0) AS ai_report_card_click_uv
        ,NVL(t3.ai_click_pv,0) AS ai_report_card_click_pv
        ,NVL(t3.good_pv,0) AS ai_report_good_click

FROM
(
    SELECT regexp_replace(substr(t1.partition_date,1,10),'-','') as partition_date
            ,device_os_type
            ,active_type
            ,channel
            ,count(distinct t1.device_id) as dau
            ,count(case when date_add(t1.partition_date,1)=t2.partition_date then t2.device_id end) as retention_num2
            ,count(case when date_add(t1.partition_date,2)=t2.partition_date then t2.device_id end) as retention_num3
            ,count(case when date_add(t1.partition_date,6)=t2.partition_date then t2.device_id end) as retention_num7
    FROM
    (
        SELECT partition_date,a.device_os_type,b.active_type,device_id,v.channel
        FROM
        (
            SELECT concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) AS partition_date
                    ,array(device_os_type,'合计') as device_os_type
                    ,array(CASE WHEN active_type = '4'  THEN '老活跃设备'
                          WHEN active_type  IN ('1','2')  THEN '新增设备' END,'合计') AS active_type
                    ,device_id
                    ,array(CASE WHEN tmp.is_ai_channel='true' THEN 'AI' ELSE '其他' END , '合计') as channel
            FROM online.ml_device_day_active_status m
                LEFT JOIN
                (SELECT code,is_spam,is_ai_channel,partition_day
                    FROM DIM.DIM_AI_CHANNEL_ZP_NEW
                    WHERE partition_day =regexp_replace(DATE_SUB(current_date,1) ,'-',''))tmp
                on first_channel_source_type=tmp.code and m.partition_date=tmp.partition_day
            WHERE partition_date=regexp_replace(DATE_SUB(current_date,1) ,'-','')
            AND active_type IN ('1','2','4')
            AND first_channel_source_type not IN ('yqxiu1','yqxiu2','yqxiu3','yqxiu4','yqxiu5','mxyc1','mxyc2','mxyc3'
                    ,'wanpu','jinshan','jx','maimai','zhuoyi','huatian','suopingjingling','mocha','mizhe','meika','lamabang'
                    ,'js-az1','js-az2','js-az3','js-az4','js-az5','jfq-az1','jfq-az2','jfq-az3','jfq-az4','jfq-az5','toufang1'
                    ,'toufang2','toufang3','toufang4','toufang5','toufang6','TF-toufang1','TF-toufang2','TF-toufang3','TF-toufang4'
                    ,'TF-toufang5','tf-toufang1','tf-toufang2','tf-toufang3','tf-toufang4','tf-toufang5','benzhan','promotion_aso100'
                    ,'promotion_qianka','promotion_xiaoyu','promotion_dianru','promotion_malioaso','promotion_malioaso-shequ'
                    ,'promotion_shike','promotion_julang_jl03','promotion_zuimei','','unknown')
            AND first_channel_source_type not LIKE 'promotion\_jf\_%'
        )mas
        lateral view explode(mas.device_os_type ) a as device_os_type
        lateral view explode(mas.active_type ) b as active_type
        lateral view explode(mas.channel ) v as channel
    )t1
    LEFT JOIN
    (--活跃设备
        SELECT device_id
                ,concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) AS partition_date
        FROM online.ml_device_day_active_status
        WHERE partition_date=regexp_replace(DATE_SUB(current_date,1) ,'-','')
    )t2
    ON t1.device_id=t2.device_id
    left join
    ( -- 去掉黑名单设备
        select distinct device_id
        from ML.ML_D_CT_DV_DEVICECLEAN_DIMEN_D
        where PARTITION_DAY = regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND is_abnormal_device = 'true'
    )spam_pv
    on t1.device_id =spam_pv.device_id
    WHERE spam_pv.device_id IS NULL
    group by t1.partition_date,device_os_type,active_type,channel
)t1
left join
(
    SELECT t1.partition_date
            ,device_os_type
            ,active_type
            ,channel
            ,count(distinct t3.cl_id) as home_click_uv
            ,sum(t3.pv) as home_click_pv
            ,count(distinct t2.cl_id) as good_uv
            ,sum(t2.pv) as good_pv
            ,round(sum(page_stay)/count(distinct t4.cl_id)/60,2) as avg_page_stay
    FROM
    (
        SELECT partition_date,a.device_os_type,b.active_type,device_id,v.channel
        FROM
        (
            SELECT partition_date
                    ,array(device_os_type,'合计') as device_os_type
                    ,array(CASE WHEN active_type = '4'  THEN '老活跃设备'
                          WHEN active_type  IN ('1','2')  THEN '新增设备' END,'合计') AS active_type
                    ,device_id
                    ,array(CASE WHEN tmp.is_ai_channel='true' THEN 'AI' ELSE '其他' END , '合计') as channel
            FROM online.ml_device_day_active_status m
                LEFT JOIN
                (SELECT code,is_spam,is_ai_channel,partition_day
                    FROM DIM.DIM_AI_CHANNEL_ZP_NEW
                    WHERE partition_day=regexp_replace(DATE_SUB(current_date,1) ,'-',''))tmp
                on first_channel_source_type=tmp.code and m.partition_date=tmp.partition_day
            WHERE partition_date=regexp_replace(DATE_SUB(current_date,1) ,'-','')
            AND active_type IN ('1','2','4')
            AND first_channel_source_type not IN ('yqxiu1','yqxiu2','yqxiu3','yqxiu4','yqxiu5','mxyc1','mxyc2','mxyc3'
                    ,'wanpu','jinshan','jx','maimai','zhuoyi','huatian','suopingjingling','mocha','mizhe','meika','lamabang'
                    ,'js-az1','js-az2','js-az3','js-az4','js-az5','jfq-az1','jfq-az2','jfq-az3','jfq-az4','jfq-az5','toufang1'
                    ,'toufang2','toufang3','toufang4','toufang5','toufang6','TF-toufang1','TF-toufang2','TF-toufang3','TF-toufang4'
                    ,'TF-toufang5','tf-toufang1','tf-toufang2','tf-toufang3','tf-toufang4','tf-toufang5','benzhan','promotion_aso100'
                    ,'promotion_qianka','promotion_xiaoyu','promotion_dianru','promotion_malioaso','promotion_malioaso-shequ'
                    ,'promotion_shike','promotion_julang_jl03','promotion_zuimei','','unknown')
            AND first_channel_source_type not LIKE 'promotion\_jf\_%'
        )mas
        lateral view explode(mas.device_os_type ) a as device_os_type
        lateral view explode(mas.active_type ) b as active_type
        lateral view explode(mas.channel ) v as channel
    )t1
    left join
    (
        SELECT partition_date,cl_id,count(distinct time_str) as pv
        from online.bl_hdfs_maidian_updates
        WHERE partition_date=regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND action='on_click_card'
        AND params['page_name'] ='home'
        and params['card_content_type'] in ('diary','user_post','answer','qa')--首页内容卡片点击，未限制tab
       GROUP BY partition_date,cl_id
    )t3
    ON t1.partition_date=t3.partition_date AND t1.device_id=t3.cl_id
    left join
    (
        SELECT partition_date
                ,cl_id
                ,count(distinct time_str) as pv
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date=regexp_replace(DATE_SUB(current_date,1) ,'-','')
        and referrer='home'
        AND action = 'page_view'
        and params['is_push']=0
        -- and params['is_first']=1
        AND page_name IN ('diary_detail','topic_detail','post_detail','user_post_detail','doctor_post_detail','question_detail','answer_detail','question_answer_detail',
                          'video_steep','article_detail','wiki_detail','product_detail','wiki_brand','wiki_collect','welfare_detail')--9月11日新增了可以跳转商详页评论的日记卡片
        and page_stay>=20
        group by partition_date,cl_id
    )t2
    ON t3.partition_date=t2.partition_date
         AND t3.cl_id=t2.cl_id
    left join
    (
        SELECT partition_date
                ,cl_id
                ,sum(page_stay) as page_stay
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date=regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND action = 'page_view'
        AND page_name IN ('diary_detail','topic_detail','post_detail','user_post_detail','doctor_post_detail','question_detail','answer_detail','question_answer_detail',
                          'video_steep','article_detail','wiki_detail','product_detail','wiki_brand','wiki_collect')
        and page_stay>=0 AND page_stay<1000
        group by partition_date,cl_id
    )t4
    ON t1.partition_date=t4.partition_date AND t1.device_id=t4.cl_id
    left join
    ( -- 去掉黑名单设备
        select distinct device_id
        from ML.ML_D_CT_DV_DEVICECLEAN_DIMEN_D
        where PARTITION_DAY = regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND is_abnormal_device = 'true'
    )spam_pv
    on t1.device_id =spam_pv.device_id
    WHERE spam_pv.device_id IS NULL
    group by t1.partition_date ,device_os_type,active_type,channel
)t2
on t1.partition_date=t2.partition_date
and t1.active_type=t2.active_type
and t1.device_os_type=t2.device_os_type
and t1.channel=t2.channel
left join
(
    SELECT t1.partition_date
            ,device_os_type
            ,active_type
            ,channel
            ,count(distinct t4.cl_id) as ai_report_uv
            ,count(distinct t3.cl_id) as ai_click_uv
            ,sum(t3.pv) as ai_click_pv
            ,count(distinct t2.cl_id) as good_uv
            ,sum(t2.pv) as good_pv
    FROM
    (
        SELECT partition_date,a.device_os_type,b.active_type,device_id,v.channel
        FROM
        (
            SELECT partition_date
                    ,array(device_os_type,'合计') as device_os_type
                    ,array(CASE WHEN active_type = '4'  THEN '老活跃设备'
                          WHEN active_type  IN ('1','2')  THEN '新增设备' END,'合计') AS active_type
                    ,device_id
                    ,array(CASE WHEN tmp.is_ai_channel='true' THEN 'AI' ELSE '其他' END , '合计') as channel
            FROM online.ml_device_day_active_status m
                LEFT JOIN
                (SELECT code,is_spam,is_ai_channel,partition_day
                    FROM DIM.DIM_AI_CHANNEL_ZP_NEW
                    WHERE partition_day=regexp_replace(DATE_SUB(current_date,1) ,'-',''))tmp
                on first_channel_source_type=tmp.code and m.partition_date=tmp.partition_day
            WHERE partition_date=regexp_replace(DATE_SUB(current_date,1) ,'-','')
            AND active_type IN ('1','2','4')
            AND first_channel_source_type not IN ('yqxiu1','yqxiu2','yqxiu3','yqxiu4','yqxiu5','mxyc1','mxyc2','mxyc3'
                    ,'wanpu','jinshan','jx','maimai','zhuoyi','huatian','suopingjingling','mocha','mizhe','meika','lamabang'
                    ,'js-az1','js-az2','js-az3','js-az4','js-az5','jfq-az1','jfq-az2','jfq-az3','jfq-az4','jfq-az5','toufang1'
                    ,'toufang2','toufang3','toufang4','toufang5','toufang6','TF-toufang1','TF-toufang2','TF-toufang3','TF-toufang4'
                    ,'TF-toufang5','tf-toufang1','tf-toufang2','tf-toufang3','tf-toufang4','tf-toufang5','benzhan','promotion_aso100'
                    ,'promotion_qianka','promotion_xiaoyu','promotion_dianru','promotion_malioaso','promotion_malioaso-shequ'
                    ,'promotion_shike','promotion_julang_jl03','promotion_zuimei','','unknown')
            AND first_channel_source_type not LIKE 'promotion\_jf\_%'
        )mas
        lateral view explode(mas.device_os_type ) a as device_os_type
        lateral view explode(mas.active_type ) b as active_type
        lateral view explode(mas.channel ) v as channel
    )t1
    left join
    (--good click
        SELECT partition_date
                ,cl_id
                ,count(distinct time_str) as pv
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date=regexp_replace(DATE_SUB(current_date,1) ,'-','')
        and referrer in ('report_result','face_detect_result','float_tag_detail')
        AND action = 'page_view'
        -- and params['is_first']=1
        AND page_name IN ('diary_detail','topic_detail','post_detail','user_post_detail','doctor_post_detail','question_detail','answer_detail','question_answer_detail',
                          'video_steep','article_detail','wiki_detail','product_detail','wiki_brand','wiki_collect')
        and page_stay>=20
        group by partition_date,cl_id
    )t2
    ON t1.partition_date=t2.partition_date
         AND t1.device_id=t2.cl_id
    left join
    (
        SELECT cl_id,partition_date,count(distinct time_str) as pv
        FROM  online.bl_hdfs_maidian_updates
        WHERE partition_date = regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND action = 'on_click_card'
        and page_name in ('report_result','face_detect_result','float_tag_detail')   --ai测颜值、ai测肤质、模拟整形结果页
        AND params['card_content_type'] in ('diary','user_post','answer','qa')
        -- AND params['tab_name'] in ('猜你喜欢','为你定制','reference_case')--不限制tab name，只要是从ai结果页到内容页的就算
        group by cl_id,partition_date
    )t3
    ON t1.partition_date=t3.partition_date AND t1.device_id=t3.cl_id
    left join
    (
        SELECT cl_id,partition_date,count(distinct time_str) as pv
        FROM  online.bl_hdfs_maidian_updates
        WHERE partition_date = regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND action = 'page_view'
        and page_name in ('report_result','face_detect_result','float_tag_detail')   --ai测颜值、ai测肤质、模拟整形结果页
        -- AND params['card_content_type'] in ('diary','user_post','answer','qa')
        -- AND params['tab_name'] in ('猜你喜欢','为你定制','reference_case')--不限制tab name，只要是从ai结果页到内容页的就算
        group by cl_id,partition_date
    )t4
    ON t1.partition_date=t4.partition_date AND t1.device_id=t4.cl_id
    left join
    ( -- 去掉黑名单设备
        select distinct device_id
        from ML.ML_D_CT_DV_DEVICECLEAN_DIMEN_D
        where PARTITION_DAY = regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND is_abnormal_device = 'true'
    )spam_pv
    on t1.device_id =spam_pv.device_id
    WHERE spam_pv.device_id IS NULL
    group by t1.partition_date ,device_os_type,active_type,channel
)t3
on t1.partition_date=t3.partition_date
and t1.active_type=t3.active_type
and t1.device_os_type=t3.device_os_type
and t1.channel=t3.channel;



INSERT OVERWRITE TABLE pm.tl_pm_content_retention PARTITION (PARTITION_DAY = ${partition_day})


SELECT
        day_id
        ,device_os_type
        ,active_type
        ,channel
        ,dau
        ,COALESCE(ROUND(retention_num/dau*100,2),0) AS retention_rate
        ,home_good_click_uv
        ,COALESCE(ROUND(home_good_click_retention_num*dau/home_good_click_uv/retention_num,2),0) as home_good_click_quality
        ,home_ungood_click_uv
        ,COALESCE(ROUND(home_ungood_click_retention_num*dau/home_ungood_click_uv/retention_num,2),0) as home_ungood_click_quality
        ,no_click_uv
        ,COALESCE(ROUND(no_click_uv_retention_num*dau/no_click_uv/retention_num,2),0) as no_click_uv_quality
        ,COALESCE(ROUND(home_good_click_uv_2*dau/home_good_click_uv/retention_num,2),0) as home_good_click_retention_quality
FROM
(
    SELECT regexp_replace(substr(t1.partition_date,1,10),'-','') as day_id
            ,device_os_type
            ,active_type
            ,channel
            ,count(distinct t1.device_id) as dau
            ,count(distinct t2.device_id) as retention_num
            ,count(distinct t3.cl_id) as home_good_click_uv
            ,count(distinct t5.cl_id) as home_good_click_uv_2
            ,count(distinct case when t3.cl_id is not null then t2.device_id end) as home_good_click_retention_num
            ,count(distinct case when t4.cl_id is not null and t3.cl_id is null then t4.cl_id end) as home_ungood_click_uv
            ,count(distinct case when t4.cl_id is not null and t3.cl_id is null then t2.device_id end) as home_ungood_click_retention_num
            ,count(distinct case when t4.cl_id is null and t3.cl_id is null then t1.device_id end) as no_click_uv
            ,count(distinct case when t4.cl_id is not null and t3.cl_id is null then t2.device_id end) as no_click_uv_retention_num

    FROM
    (
        SELECT partition_date,a.device_os_type,b.active_type,device_id,v.channel
        FROM
        (
            SELECT concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) AS partition_date
                    ,array(device_os_type,'合计') as device_os_type
                    ,array(CASE WHEN active_type = '4'  THEN '老活跃设备'
                          WHEN active_type  IN ('1','2')  THEN '新增设备' END,'合计') AS active_type
                    ,device_id
                    ,array(CASE WHEN tmp.is_ai_channel='true' THEN 'AI' ELSE '其他' END , '合计') as channel
            FROM online.ml_device_day_active_status m
                LEFT JOIN
                (SELECT code,is_spam,is_ai_channel,partition_day
                    FROM DIM.DIM_AI_CHANNEL_ZP_NEW
                    WHERE partition_day >=regexp_replace(DATE_SUB(current_date,2) ,'-','') and partition_day<=regexp_replace(DATE_SUB(current_date,1) ,'-',''))tmp
                on first_channel_source_type=tmp.code and m.partition_date=tmp.partition_day
            WHERE partition_date>=regexp_replace(DATE_SUB(current_date,2) ,'-','') and partition_date<=regexp_replace(DATE_SUB(current_date,1) ,'-','')
            AND active_type IN ('1','2','4')
            AND first_channel_source_type not IN ('yqxiu1','yqxiu2','yqxiu3','yqxiu4','yqxiu5','mxyc1','mxyc2','mxyc3'
                    ,'wanpu','jinshan','jx','maimai','zhuoyi','huatian','suopingjingling','mocha','mizhe','meika','lamabang'
                    ,'js-az1','js-az2','js-az3','js-az4','js-az5','jfq-az1','jfq-az2','jfq-az3','jfq-az4','jfq-az5','toufang1'
                    ,'toufang2','toufang3','toufang4','toufang5','toufang6','TF-toufang1','TF-toufang2','TF-toufang3','TF-toufang4'
                    ,'TF-toufang5','tf-toufang1','tf-toufang2','tf-toufang3','tf-toufang4','tf-toufang5','benzhan','promotion_aso100'
                    ,'promotion_qianka','promotion_xiaoyu','promotion_dianru','promotion_malioaso','promotion_malioaso-shequ'
                    ,'promotion_shike','promotion_julang_jl03','promotion_zuimei','','unknown')
            AND first_channel_source_type not LIKE 'promotion\_jf\_%'
        )mas
        lateral view explode(mas.device_os_type ) a as device_os_type
        lateral view explode(mas.active_type ) b as active_type
        lateral view explode(mas.channel ) v as channel
    )t1
    LEFT JOIN
    (--活跃设备
        SELECT device_id
                ,concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) AS partition_date
        FROM online.ml_device_day_active_status
        WHERE partition_date>=regexp_replace(DATE_SUB(current_date,2) ,'-','') and partition_date<=regexp_replace(DATE_SUB(current_date,1) ,'-','')
    )t2
    ON t1.device_id=t2.device_id and date_add(t1.partition_date,1)=t2.partition_date

    left join
    (
        SELECT concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) AS partition_date
                ,cl_id
                ,count(distinct time_str) as pv
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date>=regexp_replace(DATE_SUB(current_date,2) ,'-','') and partition_date<=regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND action='on_click_card'
        AND page_name ='home'
        and params['card_content_type'] in ('diary','user_post','answer','qa')
        group by partition_date,cl_id
    )t4
    on t1.partition_date=t4.partition_date and t1.device_id=t4.cl_id
    left join
    (
        SELECT concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) AS partition_date
                ,cl_id
                ,count(distinct time_str) as pv
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date>=regexp_replace(DATE_SUB(current_date,2) ,'-','') and partition_date<=regexp_replace(DATE_SUB(current_date,1) ,'-','')
        and referrer='home'
        AND action = 'page_view'
        and params['is_push']=0--ios从push点击进入的数据referrer也为首页，故需要去掉（可能存在个别时期的数据有问题）
        AND page_name IN ('diary_detail','topic_detail','post_detail','user_post_detail','doctor_post_detail','question_detail','answer_detail','question_answer_detail',
                          'video_steep','article_detail','wiki_detail','product_detail','wiki_brand','wiki_collect','welfare_detail')
        and page_stay>=20
        group by partition_date,cl_id
    )t3
    on t4.partition_date=t3.partition_date and t4.cl_id=t3.cl_id
    LEFT JOIN
    (--活跃设备
        SELECT concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) AS partition_date
                ,cl_id
                ,count(distinct time_str) as pv
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date>=regexp_replace(DATE_SUB(current_date,2) ,'-','') and partition_date<=regexp_replace(DATE_SUB(current_date,1) ,'-','')
        and referrer='home'
        AND action = 'page_view'
        AND page_name IN ('diary_detail','topic_detail','post_detail','user_post_detail','doctor_post_detail','question_detail','answer_detail','question_answer_detail',
                          'video_steep','article_detail','wiki_detail','product_detail','wiki_brand','wiki_collect','welfare_detail')
        and page_stay>=20
        group by partition_date,cl_id
    )t5
    ON t3.cl_id=t5.cl_id and date_add(t3.partition_date,1)=t5.partition_date
    left join
    ( -- 去掉黑名单设备
        select distinct device_id
        from ML.ML_D_CT_DV_DEVICECLEAN_DIMEN_D
        where PARTITION_DAY = regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND is_abnormal_device = 'true'
    )spam_pv
    on t1.device_id =spam_pv.device_id
    WHERE spam_pv.device_id IS NULL
    group by t1.partition_date,device_os_type,active_type,channel
)t1;


INSERT OVERWRITE TABLE pm.tl_pm_search_content PARTITION (PARTITION_DAY = ${partition_day})
SELECT
    t1.partition_date as day_id
    ,device_os_type
    ,active_type
    ,channel
    ,count(distinct t1.device_id) as `DAU`
    ,count(distinct case when t4.search_pv>0 then t4.cl_id end) as search_uv
    ,concat(round(count(distinct case when t4.search_pv>0 then t4.cl_id end)/count(distinct t1.device_id)*100,2),'%') as search_uv_in_dau
    ,count(distinct t2.cl_id) as do_search_uv
    ,sum(t2.all_search_pv) as do_search_pv
    ,concat(round(count(distinct t2.cl_id)/count(distinct t1.device_id)*100,2),'%') as do_search_rate
    ,round(sum(t2.all_search_pv)/count(distinct t2.cl_id),2) as search_times
    ,count(distinct case when referrer_search_diary_pv>0 then t4.cl_id end) search_diary_to_content_uv
    ,sum(referrer_search_diary_pv) search_diary_to_content_pv
    ,concat(round(count(distinct case when referrer_search_diary_pv>0 then t4.cl_id end )/count(distinct case when t4.search_pv>0 then t4.cl_id end)*100,2),'%') search_diary_to_content_uv_rate
    ,count(distinct case when referrer_search_qa_pv>0 then t4.cl_id end ) search_qa_to_content_uv
    ,sum(referrer_search_qa_pv) search_qa_to_content_pv
    ,concat(round(count(distinct case when referrer_search_qa_pv>0 then t4.cl_id end )/count(distinct case when t4.search_pv>0 then t4.cl_id end)*100,2),'%') search_qa_to_content_uv_rate
    ,concat(round(sum(diary_click_pv)/sum(diary_exp_pv)*100,2),'%') diary_tab_ctr
    ,round(sum(diary_click_pv)/count(distinct case when diary_click_pv>0 then t6.device_id end),2) diary_tab_pv_per_uv
    ,concat(round(sum(qa_click_pv)/sum(qa_exp_pv)*100,2),'%') qa_tab_ctr
    ,round(sum(qa_click_pv)/count(distinct case when qa_click_pv>0 then t6.device_id end),2) qa_tab_pv_per_uv
    ,round(sum(referrer_search_pv)/count(distinct case when t4.search_pv>0 then t4.cl_id end),2) as  content_uv_in_search_uv
    ,concat(round(count(distinct case when total_diary_second_pv>0 then t4.cl_id end )/count(distinct case when t4.search_pv>0 then t4.cl_id end)*100,2),'%') diary_second_pv_in_search_uv
    ,concat(round(count(distinct case when total_qa_second_pv>0 then t4.cl_id end )/count(distinct case when t4.search_pv>0 then t4.cl_id end)*100,2),'%') qa_second_pv_in_search_uv
    ,round(sum(referrer_search_pagestay)/count(distinct case when t4.search_pv>0 then t4.cl_id end),2) as content_pagestay_in_search_uv
    ,round(sum(business_id_num)/count(distinct t2.cl_id),2) as avg_contents
    ,concat(round(count(distinct t3.cl_id)/count(distinct t2.cl_id)*100,2),'%') as  search_retention
FROM
(  --dau
    SELECT mas.partition_date,t2.active_type,t2.device_os_type,t2.channel,device_id
    FROM
    (
        SELECT
        concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) as partition_date
        ,m.device_id
        ,array(device_os_type ,'合计') as device_os_type
        ,array(case WHEN active_type = '4'  THEN '老活'
              WHEN active_type  in ('1','2')  then '新增' END ,'合计') as active_type
        ,array(CASE WHEN is_ai_channel = 'true' THEN 'AI'  ELSE '其他' END , '合计') as channel
        FROM online.ml_device_day_active_status m
            LEFT JOIN
            (SELECT code,is_ai_channel,partition_day
             FROM DIM.DIM_AI_CHANNEL_ZP_NEW
             WHERE partition_day=regexp_replace(DATE_SUB(current_date,1) ,'-','') ) tmp
            ON  m.partition_date=tmp.partition_day AND first_channel_source_type=code
        where partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND active_type in ('1','2','4')
    ) mas
    LATERAL VIEW explode(mas.channel) t2 AS channel
    LATERAL VIEW explode(mas.device_os_type) t2 AS device_os_type
    LATERAL VIEW explode(mas.active_type) t2 AS active_type
)t1
left JOIN
(
    --搜索pvuv
    SELECT concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) as partition_date,cl_id
        ,count(1) as all_search_pv
    FROM
    (
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND ((action = 'do_search' AND params['input_type']<>'everyone_watch')
                or action='search_result_click_search')

        UNION all
        --首页大家都在看
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND action = 'do_search'
          and params['input_type']='everyone_watch'
          and params['tab']='精选'
          and page_name='home'
          AND params['query'] not in ('AI测颜值','AI测肤质')  --这两个词不跳转搜索结果页

        union all
        --灰度搜索的点击搜索动作
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND action = 'on_click_card'
          AND params['page_name']='search_home'

        union all
        --首页大家都在看的另一种埋点
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND action = 'on_click_card'
          AND params['in_page_pos']='猜你喜欢'
          --AND params['tab_name']='精选'
          AND params['card_type']='search_word'
          AND params['card_name'] not in ('AI测颜值','AI测肤质')  --这两个词不跳转搜索结果页
          --AND page_name='home' android的page_name为空

        union all
        --美购首页热搜词
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND action = 'on_click_card'
          AND params['page_name']='welfare_home'
          AND params['card_type'] ='search_word'
          AND params['in_page_pos']='大家都在搜'

        union all
        --文内高亮词搜索
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND action = 'on_click_card'
          AND params['card_type'] ='highlight_word'
    )click
    group by partition_date,cl_id
)t2
on t1.partition_date=t2.partition_date and t1.device_id=t2.cl_id
left join
(
    --搜索pvuv
    SELECT concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) as partition_date,cl_id
        ,count(1) as all_search_pv
    FROM
    (
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND ((action = 'do_search' AND params['input_type']<>'everyone_watch')
                or action='search_result_click_search')

        UNION all
        --首页大家都在看
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND action = 'do_search'
          and params['input_type']='everyone_watch'
          and params['tab']='精选'
          and page_name='home'
          AND params['query'] not in ('AI测颜值','AI测肤质')  --这两个词不跳转搜索结果页

        union all
        --灰度搜索的点击搜索动作
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND action = 'on_click_card'
          AND params['page_name']='search_home'

        union all
        --首页大家都在看的另一种埋点
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND action = 'on_click_card'
          AND params['in_page_pos']='猜你喜欢'
          --AND params['tab_name']='精选'
          AND params['card_type']='search_word'
          AND params['card_name'] not in ('AI测颜值','AI测肤质')  --这两个词不跳转搜索结果页
          --AND page_name='home' android的page_name为空

        union all
        --美购首页热搜词
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND action = 'on_click_card'
          AND params['page_name']='welfare_home'
          AND params['card_type'] ='search_word'
          AND params['in_page_pos']='大家都在搜'

        union all
        --文内高亮词搜索
        SELECT cl_id,partition_date
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND action = 'on_click_card'
          AND params['card_type'] ='highlight_word'
    )click
    group by partition_date,cl_id
)t3
on date_add(t2.partition_date,1)=t3.partition_date and t2.cl_id=t3.cl_id

left JOIN
(
    --页面浏览pvuv
    SELECT
        concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) as partition_date,cl_id
        ,count(CASE WHEN page_name in ('search_home','search_home_more','search_home_welfare','search_home_diary','search_home_wiki','search_home_post','search_home_hospital','search_home_doctor'
                    ,'search_result_diary','search_result_doctor','search_result_hospital','search_result_more'
                    ,'search_result_more_infomation','search_result_more_user','search_result_post','search_result_welfare'
                    ,'search_result_wiki','search_result_question_answer') THEN page.cl_id END) as search_pv
        ,count(CASE when referrer in  ('search_result_diary') and page_name in ('diary_detail','post_detail','user_post_detail','doctor_post_detail') THEN page.cl_id END) as referrer_search_diary_pv
        ,count(CASE when referrer in  ('search_result_question_answer') and page_name in ('question_answer_detail','answer_detail','question_detail') THEN page.cl_id END) as referrer_search_qa_pv
        ,count(case when referrer in ('search_result_diary','search_result_question_answer') and page_name in ('diary_detail','post_detail','user_post_detail','doctor_post_detail','question_answer_detail','answer_detail','question_detail') then page.cl_id end) as referrer_search_pv
        ,sum(CASE WHEN referrer in  ('search_result_diary','search_result_question_answer') and page_name in ('diary_detail','post_detail','user_post_detail','doctor_post_detail','question_answer_detail','answer_detail','question_detail') and page_stay >= '0' and page_stay < '1000' THEN page.page_stay END) as  referrer_search_pagestay

    FROM
    (
        SELECT cl_id,partition_date,page_name,params['referrer'] as referrer,page_stay
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
          AND action='page_view'
          AND page_name in ('search_home','search_home_more','search_home_welfare','search_home_diary','search_home_wiki','search_home_post','search_home_hospital','search_home_doctor'
                    ,'diary_detail','topic_detail','post_detail','user_post_detail','doctor_post_detail','question_detail','answer_detail'
                    ,'question_answer_detail','article_detail'
                    ,'search_result_diary','search_result_doctor','search_result_hospital','search_result_more'
                    ,'search_result_more_infomation','search_result_more_user','search_result_post','search_result_welfare'
                    ,'search_result_wiki','search_result_question_answer')
    )page
    group by partition_date,cl_id
)t4
on t1.partition_date=t4.partition_date and t1.device_id=t4.cl_id
left JOIN
(   --搜索结果页的二跳率
    SELECT nvl(nvl(a.partition_date,b.partition_date),c.partition_date) as partition_date
            ,nvl(nvl(a.cl_id,b.cl_id),c.cl_id) as cl_id
            ,nvl(diary_navbar_pv,0)+nvl(diary_service_pv,0)+nvl(diary_content_pv,0)*0.2+nvl(diary_cons_pv,0) as total_diary_second_pv
            ,nvl(qa_navbar_pv,0)+nvl(qa_service_pv,0)+nvl(qa_content_pv,0)*0.2+nvl(qa_cons_pv,0) as total_qa_second_pv

    FROM
    (
        --搜索框点击行为,高亮词点击
        SELECT concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) as partition_date,cl_id
              ,count(distinct case when (referrer='search_result_diary' or json_split(params['referrer_link'])[size(json_split(params['referrer_link']))-1]='search_result_diary') then time_str end) as diary_navbar_pv
              ,count(distinct case when (referrer='search_result_question_answer' or json_split(params['referrer_link'])[size(json_split(params['referrer_link']))-1]='search_result_question_answer') then time_str end) as qa_navbar_pv
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date = regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND (action in ('on_click_navbar_search','do_search') or (action='on_click_card' and params['card_type']='highlight_word'))
        AND page_name IN ('diary_detail','topic_detail','post_detail','user_post_detail','doctor_post_detail','question_detail','answer_detail','question_answer_detail')
        AND (referrer in ('search_result_diary','search_result_question_answer') or
              (params['referrer_link'] like '%[%' and
               json_split(params['referrer_link'])[size(json_split(params['referrer_link']))-1]in ('search_result_diary','search_result_question_answer')))
        group by partition_date,cl_id
    )a
    full join
    (
        --点击美购卡片,内容卡片
        SELECT  concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) as partition_date,cl_id
                ,count(distinct case when (referrer='search_result_diary' or json_split(params['referrer_link'])[size(json_split(params['referrer_link']))-1]='search_result_diary') and params['card_content_type']in ('service') then array( params['card_id'],app_session_id) end) as diary_service_pv
                ,count(distinct case when (referrer='search_result_diary' or json_split(params['referrer_link'])[size(json_split(params['referrer_link']))-1]='search_result_diary') and params['card_content_type']in ('qa','diary','user_post','answer') then array( params['card_id'],app_session_id) end) as diary_content_pv
                ,count(distinct case when (referrer='search_result_question_answer' or json_split(params['referrer_link'])[size(json_split(params['referrer_link']))-1]='search_result_question_answer') and params['card_content_type']in ('service') then array(params['card_id'],app_session_id) end) as qa_service_pv
                ,count(distinct case when (referrer='search_result_question_answer' or json_split(params['referrer_link'])[size(json_split(params['referrer_link']))-1]='search_result_question_answer') and params['card_content_type']in ('qa','diary','user_post','answer') then array(params['card_id'],app_session_id) end) as qa_content_pv
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date = regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND action='on_click_card'
        and params['card_content_type']in ('service','qa','diary','user_post','answer')
        AND page_name IN ('diary_detail','topic_detail','post_detail','user_post_detail','doctor_post_detail','question_detail','answer_detail','question_answer_detail')
        AND (referrer in ('search_result_diary','search_result_question_answer') or
              (params['referrer_link'] like '%[%' and
               json_split(params['referrer_link'])[size(json_split(params['referrer_link']))-1]in ('search_result_diary','search_result_question_answer')))
        group by partition_date,cl_id
    )b
    on a.partition_date=b.partition_date and a.cl_id=b.cl_id
    full join
    (
        --点击视频面诊
        SELECT concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) as partition_date,cl_id
                ,count(distinct case when (referrer='search_result_diary' or json_split(params['referrer_link'])[size(json_split(params['referrer_link']))-1]='search_result_diary') then time_str end ) as diary_cons_pv
                ,count(distinct case when (referrer='search_result_question_answer' or json_split(params['referrer_link'])[size(json_split(params['referrer_link']))-1]='search_result_question_answer') then time_str end ) as qa_cons_pv
        FROM online.bl_hdfs_maidian_updates
        WHERE partition_date = regexp_replace(DATE_SUB(current_date,1) ,'-','')
        AND action='on_click_button'
        and params['button_name'] in ('video_interview','referral')
        AND page_name IN ('diary_detail','topic_detail','post_detail','user_post_detail','doctor_post_detail','question_detail','answer_detail','question_answer_detail')
        AND (referrer in ('search_result_diary','search_result_question_answer') or
              (params['referrer_link'] like '%[%' and
               json_split(params['referrer_link'])[size(json_split(params['referrer_link']))-1]in ('search_result_diary','search_result_question_answer')))
        group by partition_date,cl_id
    )c
    on nvl(a.partition_date,b.partition_date)=c.partition_date and nvl(a.cl_id,b.cl_id)=c.cl_id
)t5
on t1.partition_date=t5.partition_date and t1.device_id=t5.cl_id
left JOIN
(--搜索结果页卡片精准曝光
    SELECT device_id,concat_ws('-',substr(partition_day,1,4),substr(partition_day,5,2),substr(partition_day,7,2)) as partition_date
        ,count(distinct CASE WHEN page_code='search_result_diary' THEN array(card_id,app_session_id) END) as diary_exp_pv
        ,count(CASE WHEN page_code='search_result_question_answer' THEN array(card_id,app_session_id) END) as qa_exp_pv
    FROM ml.mid_ml_c_et_pe_preciseexposure_dimen_d
    WHERE partition_day =regexp_replace(DATE_SUB(current_date,1) ,'-','')
    and action in ('page_precise_exposure','home_choiceness_card_exposure')
    and is_exposure = '1'
    and page_code in ('search_result_diary','search_result_question_answer')
    AND card_content_type IN ('answer','diary','user_post','doctor_post','question','qa')
    group by partition_day,device_id
)t6
on t1.partition_date=t6.partition_date and t1.device_id=t6.device_id
LEFT JOIN
(--搜索结果页卡片点击
    SELECT concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) as partition_date,cl_id
        ,count(distinct CASE WHEN page_name='search_result_diary' THEN array(params['card_id'],app_session_id) END) as diary_click_pv
        ,count(distinct CASE WHEN page_name='search_result_question_answer' THEN array(params['card_id'],app_session_id) END) as qa_click_pv
    FROM online.bl_hdfs_maidian_updates
    WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
    AND action = 'on_click_card'
    AND params['card_content_type'] in ('answer','diary','question','qa')
    AND page_name in ('search_result_diary','search_result_question_answer')
    GROUP BY cl_id,partition_date
)t7
on t6.partition_date=t7.partition_date and t6.device_id=t7.cl_id
left JOIN
(
    --人均阅读内容篇数
    SELECT cl_id,concat_ws('-',substr(partition_date,1,4),substr(partition_date,5,2),substr(partition_date,7,2)) as partition_date,count(DISTINCT params['business_id']) as business_id_num
    FROM online.bl_hdfs_maidian_updates
    WHERE partition_date =regexp_replace(DATE_SUB(current_date,1) ,'-','')
    AND action='page_view'
    AND page_name in ('diary_detail','topic_detail','post_detail','user_post_detail','doctor_post_detail','question_detail','answer_detail'
          ,'question_answer_detail','article_detail')
    AND referrer in ('search_result_diary','search_result_question_answer')
    AND params['business_id'] is not NULL AND params['business_id']<> ''
    GROUP BY cl_id,partition_date
)t9
on t1.partition_date=t9.partition_date and t1.device_id=t9.cl_id
left join
( -- 去掉黑名单设备
    select distinct device_id
    from ML.ML_D_CT_DV_DEVICECLEAN_DIMEN_D
    where PARTITION_DAY = regexp_replace(DATE_SUB(current_date,1) ,'-','')
    AND is_abnormal_device = 'true'
)spam_pv
on t1.device_id =spam_pv.device_id
WHERE spam_pv.device_id IS NULL
group by t1.partition_date,device_os_type,active_type,channel
